$(function () {
    $('#newsletter').submit(function(){
        var form = $(this);
        $.post(form.attr('action'), form.serialize(), function(rs){
            if (rs.success) {
                form.find('#message').show();
            }
            if (rs.hash) {
                form.find('input[name="hash"]').remove();
                form.append(rs.hash);
            }
        });
        return false;
    });
});